/**
 * Actualiza el elemento de la lista en caso de que exista en dicha lista, o lo inserta en caso de que no exista
 * @param element objeto que queremos actualizar o insertar en la lista
 * @param list lista de elementos
 */
export declare function upsertElement(element: any, list: any): any;
/**
 * Elimina el elemento de la lista
 * @param element elemento a eliminar de la lista
 * @param list lista de elementos
 */
export declare function deleteElement(element: any, list: any): any;
/** Permite copiar las propiedades de un objeto exceptuando las propiedades indicadas en keys.
 * Util para obtener los valores del filtro exceptuando las propiedades pagina y resultados.
 * La copia se realiza mediante Object.assign por lo que hay que tenerlo en cuenta por temas de propiedades anidadas
 * @param obj objeto que queremos copiar
 * @param keys array de propiedades que no queremos copiar
 */
export declare function reject(obj: any, keys: any): {
    [x: string]: any;
};
/** Permite seleccionar las propiedades de un objeto indicadas en keys, excluyendo el resto.
 * La copia se realiza mediante Object.assign por lo que hay que tenerlo en cuenta por temas de propiedades anidadas
 * @param obj objeto que queremos copiar
 * @param keys array de propiedades que queremos copiar
 */
export declare function choose(obj: any, keys: any): {
    [x: string]: any;
};
/**
 * Equivalente al Object.assign() pero realiza una copia profunda: tanto los atributos como los objetos anidados
 * Modifica el objeto target asignando los objetos pasados como parámetros
 * ejemplo: assign({a: "a", b: {id: "b"}, c: "c"},
 *                 {a: "a2", b: {id: "b2"}, d: "d"}) =>
 *                 {a: "a2", b: {id: "b2"}, c: "c", d: "d"}
 *
 * @param target objeto destino
 * @param sources objetos cuyas propiedades se leen para mergear en el objeto destino
 * @see https://stackoverflow.com/questions/27936772/how-to-deep-merge-instead-of-shallow-merge
 */
export declare function assign(target: any, ...sources: any[]): any;
